@@ -5,13 +5,14 @@ from __future__ import print_function
 
 from ._network import *
 
+from .equilibrium import *
 from .combinatorics import *
 from .complementarity import *
 from .duality import *
+from .explode import *
 from .parallelisation import *
 from ._planarity import *
 from .smoothing import *
 from .transformations import *
 
-
 __all__ = [name for name in dir() if not name.startswith('_')]
