@@ -5,6 +5,7 @@ from __future__ import division
 import os
 import time
 import json
+import sys
 
 import compas
 
@@ -88,7 +89,7 @@ class Proxy(object):
 
         numerical = Proxy('compas.numerical')
 
-        mesh = Mesh.from_obj(compas.get('faces_big.obj'))
+        mesh = Mesh.from_obj(compas.get('faces.obj'))
 
         mesh.update_default_vertex_attributes({'px': 0.0, 'py': 0.0, 'pz': 0.0})
         mesh.update_default_edge_attributes({'q': 1.0})
@@ -235,13 +236,13 @@ class Proxy(object):
             try:
                 server.ping()
             except:
-                time.sleep(0.01)
+                time.sleep(0.1)
                 count -= 1
             else:
                 success = True
                 break
         if not success:
-            raise RPCServerError("The server is no available.")
+            raise RPCServerError("The server is not available.")
 
         return server
 
@@ -338,10 +339,6 @@ if __name__ == "__main__":
 
     from compas_rhino.artists import MeshArtist
 
-    # this is not how a server proxy should be used
-    # the server should be started somewhere independently
-    # and then used in real-time
-
     numerical = Proxy('compas.numerical')
 
     mesh = Mesh.from_obj(compas.get('faces.obj'))
