@@ -3,15 +3,19 @@
 compas_blender
 ********************************************************************************
 
-.. currentmodule:: compas_blender
+.. module:: compas_blender
 
 .. toctree::
     :maxdepth: 1
 
     compas_blender.artists
+    compas_blender.conduits
     compas_blender.forms
     compas_blender.geometry
     compas_blender.helpers
+    compas_blender.inspectors
+    compas_blender.modifiers
+    compas_blender.selectors
     compas_blender.ui
     compas_blender.utilities
 
@@ -23,7 +27,7 @@ from __future__ import print_function
 from .utilities import *
 
 
-__version__ = '0.4.10'
+__version__ = '0.4.11'
 
 
 __all__ = [name for name in dir() if not name.startswith('_')]
