@@ -1,12 +1,16 @@
+
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+
+try:
+    import bpy
+except ImportError:
+    pass
+
 import os
 
 
-__author__     = ['Andrew Liew  <liew@arch.ethz.ch>']
-__copyright__  = 'Copyright 2017, Andrew Liew'
-__license__    = 'MIT License'
-__email__      = 'liew@arch.ethz.ch'
-
-
 __all__ = [
     'get_document_name',
     'get_document_filename',
@@ -16,18 +20,22 @@ __all__ = [
 
 
 def get_document_name():
+
     raise NotImplementedError
 
 
 def get_document_filename():
+
     raise NotImplementedError
 
 
 def get_document_path():
+
     raise NotImplementedError
 
 
 def get_document_dirname():
+
     raise NotImplementedError
 
 
